@@ -17,27 +17,24 @@ ___           __          ____  _       __ _   __   _____         _  __
  /_/  |_|\____/ \__/ \____//_/      |__/|__//_/ |_/   /____/ \____//_/ \__/ \___/
 """
 
-
     banner_small = """\
 ╔═╗┬ ┬┌┬┐┌─┐╔═╗╦ ╦╔╗╔  ╔═╗┬ ┬┬┌┬┐┌─┐
 ╠═╣│ │ │ │ │╠═╝║║║║║║  ╚═╗│ ││ │ ├┤ 
 ╩ ╩└─┘ ┴ └─┘╩  ╚╩╝╝╚╝  ╚═╝└─┘┴ ┴ └─┘
 """
 
-
     if width < 90:
         banner = banner_small
         height = 5
 
     panel = Panel(
         Align(
-            Text(
-                banner,
-                justify="center",
-                style="blue"
-            ),
-            vertical="middle", align="center"
+            Text(banner, justify="center", style="blue"),
+            vertical="middle",
+            align="center",
         ),
-        width=width, height=height, subtitle="by GamehunterKaan (https://auto.pwnspot.com)"
+        width=width,
+        height=height,
+        subtitle="by GamehunterKaan (https://auto.pwnspot.com)",
     )
-    console.print(panel)
\ No newline at end of file
+    console.print(panel)
